PointerSample

Struct PointerSample 

pub struct PointerSample {
    pub pointer_id: Option<u32>,
    pub phase: Option<EventPhase>,
    pub position_in_viewport: Option<[f32; 2]>,
    pub scroll_v: Option<i64>,
    pub scroll_h: Option<i64>,
    pub pressed_buttons: Option<Vec<u8>>,
    pub relative_motion: Option<[f32; 2]>,
    pub scroll_v_physical_pixel: Option<f64>,
    pub scroll_h_physical_pixel: Option<f64>,
    pub is_precision_scroll: Option<bool>,
    /* private fields */
}
A description of each sampled data point for a pointer device.

Fields

pointer_id: Option<u32>

An identifier of the pointer that issued this event. It is unique only to a specific pointer device.

phase: Option<EventPhase>

The state of this event in the pointer event stream’s state machine.

position_in_viewport: Option<[f32; 2]>

The position of this event, in the viewport’s coordinate system.

scroll_v: Option<i64>

Relative vertical scrolling displacement by detent.

scroll_h: Option<i64>

Relative horizontal scrolling displacement by detent.

pressed_buttons: Option<Vec<u8>>relative_motion: Option<[f32; 2]>

The movement of a mouse, independent of the viewport’s coordinate system.

scroll_v_physical_pixel: Option<f64>

Recommended vertical scrolling displacement by physical pixel, it is computed with accelerator, detent / mm to pixel ratio, etc.

scroll_h_physical_pixel: Option<f64>

Recommended horizontal scrolling displacement by physical pixel, it is computed with accelerator, detent / mm to pixel ratio, etc.

is_precision_scroll: Option<bool>

Indicated if the scroll event is from a precision scroll device (HI_RES mouse or touchpad). Clients may want to play interpolation animations on non precision scroll device for smooth scrolling.